"""add processing controllers table

Revision ID: 289f1fa74088
Revises: e387ec2747c2
Create Date: 2022-12-02 14:58:03.056085

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "289f1fa74088"
down_revision = "e387ec2747c2"
branch_labels = None
depends_on = None


def upgrade():
    op.create_table(
        "processing_controllers",
        sa.Column(
            "control_system",
            sa.String,
            primary_key=True,
            comment="A system capable of creating and submitting Workspaces Workflow Requests",
        ),
        sa.Column(
            "message_handler",
            sa.String,
            comment="which message formatter to use?",
        ),
        sa.Column(
            "routing_key_prefix",
            sa.String,
            comment="the prefix of the AMQP routing key for the associated handeler",
        ),
    )

    op.add_column(
        "workflow_requests",
        sa.Column(
            "controller",
            sa.String,
            sa.ForeignKey("processing_controllers.control_system"),
            comment="the system that initiated the workflow request, defaults to Workspaces (WS)",
        ),
    )

    op.execute(
        """
        INSERT INTO processing_controllers (control_system, message_handler, routing_key_prefix)
        VALUES ('WS', 'default', null)
        """
    )
    op.execute(
        """
        INSERT INTO processing_controllers (control_system, message_handler, routing_key_prefix)
        VALUES ('VLASS', 'archive', 'ws-workflow.')
        """
    )
    op.execute(
        """
        INSERT INTO processing_controllers (control_system, message_handler, routing_key_prefix)
        VALUES ('AAT', 'archive', 'ws-workflow.')
        """
    )

    op.execute(
        """
        UPDATE workflow_requests
        SET controller = 'VLASS'
        WHERE results_dir like '%vlass_%' AND workflow_name != 'pims_split'
        """
    )

    op.execute(
        """
        UPDATE workflow_requests
        SET controller = 'AAT'
        WHERE workflow_name = 'carta' and (argument->>'need_data')::boolean = true
        """
    )

    op.execute(
        """
        UPDATE workflow_requests
        SET controller = 'WS'
        WHERE controller is null
        """
    )


def downgrade():
    op.drop_column("workflow_requests", "controller")
    op.drop_table("processing_controllers")
